==> dcc-insider-plugin_0.1.4.tar.xz: BUILD/translations/dcc-insider-plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>InsiderModule</name>
    <message>
        <location filename="../insidermodule.cpp" line="30"/>
        <source>Technology Preview</source>
        <translation>技术预览</translation>
    </message>
    <message>
        <source>Currently stable launcher (dde-launcher)</source>
        <translation type="vanished">当前稳定版启动器（dde-launcher）</translation>
    </message>
    <message>
        <source>Technology preview launcher (dde-launchpad)</source>
        <translation type="vanished">技术预览版启动器（dde-launchpad）</translation>
    </message>
    <message>
        <source>New Launcher</source>
        <translation type="vanished">新版启动器</translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="37"/>
        <source>Currently stable Display Manager (lightdm)</source>
        <translation>当前稳定版显示管理器（lightdm）</translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="41"/>
        <source>Technology preview Display Manager/Window Manager (ddm/treeland)</source>
        <translation>技术预览版显示管理器/窗口管理器(ddm/treeland)</translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="45"/>
        <source>New Display Manager</source>
        <translation>新版显示管理器</translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="69"/>
        <source>Currently stable Input Method</source>
        <translation>当前稳定版输入法</translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="73"/>
        <source>Technology preview Input Method (deepin-im)</source>
        <translation>技术预览版输入法（deepin-im）</translation>
    </message>
    <message>
        <location filename="../insidermodule.cpp" line="77"/>
        <source>New Input Method</source>
        <translation>新版输入法</translation>
    </message>
</context>
</TS>

==> dcc-insider-plugin_0.1.14.tar.xz: BUILD/translations/dcc-insider-plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>InsiderModule</name>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="30"/>
        <source>Technology Preview</source>
        <translation>技术预览</translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="37"/>
        <source>Currently stable Display Manager (lightdm)</source>
        <translation>当前稳定版显示管理器（lightdm）</translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="41"/>
        <source>Technology preview Display Manager/Window Manager (ddm/treeland)</source>
        <translation>技术预览版显示管理器/窗口管理器(ddm/treeland)</translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="45"/>
        <source>New Display Manager</source>
        <translation>新版显示管理器</translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="72"/>
        <source>Currently stable Input Method</source>
        <translation>当前稳定版输入法</translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="76"/>
        <source>Technology preview Input Method (deepin-im)</source>
        <translation>技术预览版输入法（deepin-im）</translation>
    </message>
    <message>
        <location filename="../dcc-insider-plugin/insidermodule.cpp" line="80"/>
        <source>New Input Method</source>
        <translation>新版输入法</translation>
    </message>
</context>
</TS>
